@@ -6,8 +6,13 @@ from one of the aforementioned modules.
 import logging
 import warnings
 
+import yupi.core
+import yupi.generators
+import yupi.graphics
+import yupi.stats
+import yupi.tracking
+import yupi.transformations
 from yupi._differentiation import DiffMethod, WindowType
-from yupi.features import Features
 from yupi.trajectory import Trajectory, TrajectoryPoint
 from yupi.vector import Vector
 
@@ -21,10 +26,9 @@ logging.basicConfig(
 __all__ = [
     "Trajectory",
     "TrajectoryPoint",
-    "Features",
     "Vector",
     "DiffMethod",
     "WindowType",
 ]
 
-__version__ = "0.11.2"
+__version__ = "0.12.3"
