@@ -27,7 +27,6 @@ import numpy as np
 
 import yupi._differentiation as diff
 from yupi.exceptions import LoadTrajectoryError
-from yupi.features import Features
 from yupi.vector import Vector
 
 _THRESHOLD = 1e-12
@@ -259,8 +258,6 @@ class Trajectory:
                     "the same as the first value of 't'."
                 )
 
-        self.features = Features(self)
-
     def set_diff_method(
         self,
         method: diff.DiffMethod,
